/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Copyright (C) 2009 Canonical Services Ltd (www.canonical.com)
 *
 * Authors: Rodrigo Moya <rodrigo.moya@canonical.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU Lesser General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "config.h"
#include <webkit/webkit.h>
#include "u1-music-store.h"

struct _U1MusicStorePrivate {
	GtkWidget *web_viewer;
};

G_DEFINE_TYPE(U1MusicStore, u1_music_store, GTK_TYPE_VBOX)

static void
u1_music_store_finalize (GObject *object)
{
	U1MusicStore *music_store = U1_MUSIC_STORE (object);

	if (music_store->priv != NULL) {
		g_free (music_store->priv);
		music_store->priv = NULL;
	}

	G_OBJECT_CLASS (u1_music_store_parent_class)->finalize (object);
}

static void
u1_music_store_class_init (U1MusicStoreClass *klass)
{
	GObjectClass *object_class = G_OBJECT_CLASS (klass);

	object_class->finalize = u1_music_store_finalize;
}

static void
u1_music_store_init (U1MusicStore *music_store)
{
	GtkWidget *scroll;

	music_store->priv = g_new0 (U1MusicStorePrivate, 1);

	/* Create web viewer object */
	scroll = gtk_scrolled_window_new (NULL, NULL);
	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
					GTK_POLICY_AUTOMATIC,
					GTK_POLICY_AUTOMATIC);
	gtk_widget_show (scroll);

	music_store->priv->web_viewer = webkit_web_view_new ();
	webkit_web_view_open (WEBKIT_WEB_VIEW (music_store->priv->web_viewer), U1_STORE_URL);
	gtk_widget_show (music_store->priv->web_viewer);
	gtk_container_add (GTK_SCROLLED_WINDOW (scroll), music_store->priv->web_viewer);

	gtk_box_pack_start (GTK_BOX (music_store), scroll, TRUE, TRUE, 3);
}

/**
 * u1_music_store_new:
 *
 * Create a new #U1MusicStore widget.
 *
 * Return value: the newly created widget.
 */
GtkWidget *
u1_music_store_new (void)
{
	U1MusicStore *music_store;

	music_store = g_object_new (U1_TYPE_MUSIC_STORE, NULL);

	return (GtkWidget *) music_store;
}
